/*=========================================================================

   Program: ParaView
   Module:    pqStatusBar.h

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#ifndef pqStatusBar_h
#define pqStatusBar_h

#include <QStatusBar>

#include "vtkNew.h"

#include "pqApplicationComponentsModule.h"

class vtkPVSystemConfigInformation;
class QProgressBar;

/**
 * pqStatusBar extends QStatusBar to support showing paraview progress.
 * It uses pqProgressManager provided by pqApplicationCore to show the
 * progress values. Internally uses pqProgressWidget to show the progress.
 * It also shows a memory status bar that automatically updates.
 */
class PQAPPLICATIONCOMPONENTS_EXPORT pqStatusBar : public QStatusBar
{
  Q_OBJECT
  typedef QStatusBar Superclass;

public:
  pqStatusBar(QWidget* parent = nullptr);
  ~pqStatusBar() override;

protected Q_SLOTS:
  void updateServerConfigInfo();
  void updateMemoryProgressBar();

protected:
  vtkNew<vtkPVSystemConfigInformation> ServerConfigsInfo;
  QProgressBar* MemoryProgressBar;

private:
  Q_DISABLE_COPY(pqStatusBar)
};

#endif
